@@ -22,6 +22,7 @@ from sherpa_client.api.jobs import get_job
 from sherpa_client.api.labels import get_labels
 from sherpa_client.api.plans import get_plan
 from sherpa_client.api.projects import get_projects, create_project
+from sherpa_client.api.shares import share_with_group, share_with_user
 from sherpa_client.client import SherpaClient
 from sherpa_client.models import (
     Credentials,
@@ -41,6 +42,7 @@ from sherpa_client.models import (
     ProjectConfigCreation,
     ProjectStatus,
     LaunchDocumentImportMultipartData, AnnotateBinaryForm, Converter, ConvertAnnotationPlan,
+    LaunchDocumentImportSegmentationPolicy, ShareMode,
 )
 from sherpa_client.types import File, Unset, UNSET, Response
 from streamlit.uploaded_file_manager import UploadedFile
@@ -159,7 +161,7 @@ class StreamlitSherpaClient:
     register = {}
 
     def __init__(
-        self, server: str, user: str, password: str, use_token=True, **kawargs
+            self, server: str, user: str, password: str, use_token=True, **kawargs
     ):
         url = server[0:-1] if server.endswith("/") else server
         self.client = SherpaClient(base_url=f"{url}/api", verify_ssl=False, timeout=100)
@@ -178,8 +180,8 @@ class StreamlitSherpaClient:
         if self.use_token:
             return self.client.token
         elif (
-            self.client.session_cookies is not None
-            and "vertx-web.session" in self.client.session_cookies
+                self.client.session_cookies is not None
+                and "vertx-web.session" in self.client.session_cookies
         ):
             return self.client.session_cookies["vertx-web.session"]
         return None
@@ -247,10 +249,10 @@ class StreamlitSherpaClient:
 
     @lru_cache()
     def get_annotators(
-        self,
-        project: Union[str, ProjectBean],
-        annotator_types: Tuple[str] = None,
-        favorite_only: bool = False,
+            self,
+            project: Union[str, ProjectBean],
+            annotator_types: Tuple[str] = None,
+            favorite_only: bool = False,
     ) -> List[ExtendedAnnotator]:
         pname = project.name if isinstance(project, ProjectBean) else project
         # st.write("get_annotators(", project, ", ", annotator_types,", ", favorite_only, ")")
@@ -274,8 +276,8 @@ class StreamlitSherpaClient:
                                     for step in definition.pipeline:
                                         # st.write("get_annotator_by_label(", server, ", ", project, ", ", label, "): step=", str(step))
                                         if (
-                                            isinstance(step, WithAnnotator)
-                                            and step.project_name != project
+                                                isinstance(step, WithAnnotator)
+                                                and step.project_name != project
                                         ):
                                             step_labels = self.get_labels(
                                                 step.project_name
@@ -306,11 +308,11 @@ class StreamlitSherpaClient:
 
     @lru_cache()
     def get_annotator_by_label(
-        self,
-        project: Union[str, ProjectBean],
-        label: str,
-        annotator_types: Tuple[str] = None,
-        favorite_only: bool = False,
+            self,
+            project: Union[str, ProjectBean],
+            label: str,
+            annotator_types: Tuple[str] = None,
+            favorite_only: bool = False,
     ) -> ExtendedAnnotator:
         pname = project.name if isinstance(project, ProjectBean) else project
         annotators = self.get_annotators(pname, annotator_types, favorite_only)
@@ -321,7 +323,7 @@ class StreamlitSherpaClient:
 
     @lru_cache()
     def _get_plan(
-        self, project: Union[str, ProjectBean], name: str
+            self, project: Union[str, ProjectBean], name: str
     ) -> NamedAnnotationPlan:
         pname = project.name if isinstance(project, ProjectBean) else project
         r = get_plan.sync_detailed(pname, name, client=self.client)
@@ -331,10 +333,10 @@ class StreamlitSherpaClient:
             r.raise_for_status()
 
     def annotate_text(
-        self,
-        project: Union[str, ProjectBean],
-        annotator: Union[str, ExtendedAnnotator],
-        text: str,
+            self,
+            project: Union[str, ProjectBean],
+            annotator: Union[str, ExtendedAnnotator],
+            text: str,
     ) -> AnnotatedDocument:
         pname = project.name if isinstance(project, ProjectBean) else project
         aname = (
@@ -367,10 +369,10 @@ class StreamlitSherpaClient:
         return file
 
     def annotate_format_text(
-        self,
-        project: Union[str, ProjectBean],
-        annotator: Union[str, ExtendedAnnotator],
-        text: str,
+            self,
+            project: Union[str, ProjectBean],
+            annotator: Union[str, ExtendedAnnotator],
+            text: str,
     ) -> File:
         pname = project.name if isinstance(project, ProjectBean) else project
         aname = (
@@ -389,10 +391,10 @@ class StreamlitSherpaClient:
             r.raise_for_status()
 
     def annotate_binary(
-        self,
-        project: Union[str, ProjectBean],
-        annotator: Union[str, ExtendedAnnotator],
-        datafile: UploadedFile,
+            self,
+            project: Union[str, ProjectBean],
+            annotator: Union[str, ExtendedAnnotator],
+            datafile: UploadedFile,
     ) -> List[AnnotatedDocument]:
         pname = project.name if isinstance(project, ProjectBean) else project
         aname = (
@@ -416,10 +418,10 @@ class StreamlitSherpaClient:
         return docs
 
     def annotate_format_binary(
-        self,
-        project: Union[str, ProjectBean],
-        annotator: Union[str, ExtendedAnnotator],
-        datafile: UploadedFile,
+            self,
+            project: Union[str, ProjectBean],
+            annotator: Union[str, ExtendedAnnotator],
+            datafile: UploadedFile,
     ) -> File:
         pname = project.name if isinstance(project, ProjectBean) else project
         aname = (
@@ -442,10 +444,10 @@ class StreamlitSherpaClient:
             r.raise_for_status()
 
     def convert_binary(
-        self,
-        converter: str,
-        parameters: dict,
-        datafile: UploadedFile,
+            self,
+            converter: str,
+            parameters: dict,
+            datafile: UploadedFile,
     ) -> List[AnnotatedDocument]:
 
         plan = ConvertAnnotationPlan.from_dict({
@@ -500,10 +502,10 @@ class StreamlitSherpaClient:
         return documents
 
     def annotate_json(
-        self,
-        project: Union[str, ProjectBean],
-        annotator: Union[str, ExtendedAnnotator],
-        datafile: UploadedFile,
+            self,
+            project: Union[str, ProjectBean],
+            annotator: Union[str, ExtendedAnnotator],
+            datafile: UploadedFile,
     ) -> List[AnnotatedDocument]:
         pname = project.name if isinstance(project, ProjectBean) else project
         aname = (
@@ -523,10 +525,10 @@ class StreamlitSherpaClient:
         return docs
 
     def annotate_format_json(
-        self,
-        project: Union[str, ProjectBean],
-        annotator: Union[str, ExtendedAnnotator],
-        datafile: UploadedFile,
+            self,
+            project: Union[str, ProjectBean],
+            annotator: Union[str, ExtendedAnnotator],
+            datafile: UploadedFile,
     ) -> File:
         pname = project.name if isinstance(project, ProjectBean) else project
         aname = (
@@ -545,11 +547,11 @@ class StreamlitSherpaClient:
             r.raise_for_status()
 
     def create_project(
-        self,
-        label: str,
-        prefix: str = "test",
-        description: str = None,
-        nature: str = "sequence_labelling",
+            self,
+            label: str,
+            prefix: str = "test",
+            description: str = None,
+            nature: str = "sequence_labelling",
     ):
         shortuuid.set_alphabet("123456789abcdefghijkmnopqrstuvwxyz_")
         pname = f"{prefix}_" + shortuuid.uuid()[: (16 - len(prefix))]
@@ -564,9 +566,42 @@ class StreamlitSherpaClient:
             project_status: ProjectStatus = r.parsed
             job_bean = self.wait_for_completion(project_status.pending_job)
             if project_status.status == "created" or self.is_success(job_bean):
-                yield project_status.project_name
+                return project_status.project_name
+            return None
+        else:
+            r.raise_for_status()
 
-    def import_documents(self, project, datafile: UploadedFile, wait_for_completion: bool = False):
+    def share_project(
+            self,
+            project: Union[str, ProjectBean],
+            group: str = None,
+            user: str = None
+    ):
+        pname = project.name if isinstance(project, ProjectBean) else project
+        if group:
+            r = share_with_group.sync_detailed(
+                pname,
+                client=self.client,
+                json_body=ShareMode(read=True, write=True),
+                group_name=group
+            )
+        elif user:
+            r = share_with_user.sync_detailed(
+                pname,
+                client=self.client,
+                json_body=ShareMode(read=True, write=True),
+                username=user
+            )
+        else:
+            raise ValueError("Group or user name must be defined")
+        if not r.is_success:
+            r.raise_for_status()
+
+    def import_documents(self, project, datafile: UploadedFile,
+                         ignore_labelling=False,
+                         segmentation_policy="compute_if_missing",
+                         split_corpus=False,
+                         wait_for_completion: bool = False):
         multipart_data = LaunchDocumentImportMultipartData(
             file=File(
                 file_name=datafile.name,
@@ -575,7 +610,10 @@ class StreamlitSherpaClient:
             )
         )
         r = launch_document_import.sync_detailed(
-            project, client=self.client, multipart_data=multipart_data
+            project, client=self.client, multipart_data=multipart_data,
+            ignore_labelling=ignore_labelling,
+            segmentation_policy=LaunchDocumentImportSegmentationPolicy(segmentation_policy),
+            split_corpus=split_corpus
         )
         if r.is_success:
             job_bean: SherpaJobBean = r.parsed
@@ -586,11 +624,12 @@ class StreamlitSherpaClient:
             r.raise_for_status()
 
     def annotate_corpus(
-        self,
-        project: Union[str, ProjectBean],
-        annotator: Union[str, ExtendedAnnotator],
-        annotator_project: Union[str, ProjectBean],
-        wait_for_completion: bool = False
+            self,
+            project: Union[str, ProjectBean],
+            annotator: Union[str, ExtendedAnnotator],
+            annotator_project: Union[str, ProjectBean],
+            email_notification: bool = False,
+            wait_for_completion: bool = False
     ):
         pname = project.name if isinstance(project, ProjectBean) else project
         apname = (
@@ -602,7 +641,7 @@ class StreamlitSherpaClient:
             annotator.name if isinstance(annotator, ExtendedAnnotator) else annotator
         )
         r = annotate_corpus_with.sync_detailed(
-            pname, aname, client=self.client, annotator_project=apname
+            pname, aname, client=self.client, annotator_project=apname, email_notification=email_notification
         )
         if r.is_success:
             job_bean: SherpaJobBean = r.parsed
@@ -629,7 +668,6 @@ class StreamlitSherpaClient:
                 )
         return job_bean
 
-
 # def main():
 #     url_input = "https://sherpa-sandbox.kairntech.com/"
 #     url = url_input[0:-1] if url_input.endswith('/') else url_input
